# GENERATED FILE - DO NOT EDIT
VERSION = '201802281026'
BUILDS = {'Darwin': {'sha256': 'ed1f82afeef43915f2c95569fab0d52fe85b261ac54f21cc45145f6bc4ab5c89',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201802281026-OSXIntel64.zip'},
 'Docker': {'tag': '201802281026'},
 'Linux': {'sha256': '8d1b4b772f872edc57db5faef94701b156aabdda68950fdabb63f069bf357140',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201802281026-Linux64.zip'}}